@@ -3,8 +3,6 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
  * This file contains Original Code and/or Modifications of Original Code
  * as defined in and that are subject to the Apple Public Source License
  * Version 2.0 (the 'License'). You may not use this file except in
@@ -40,10 +38,6 @@ class IOUSBMassStorageUFIDevice : public IOSCSIPrimaryCommandsDevice
 private:
 	static void			AsyncReadWriteComplete( SCSITaskIdentifier	completedTask );
 	
-	static bool			ServerKeyswitchCallback (	void *		target,
-													void *		refCon,
-													IOService *	newService );
-	
 protected:
     // Reserve space for future expansion.
     struct IOUSBMassStorageUFIDeviceExpansionData
